@@ -1,6 +1,6 @@
 from io import StringIO
 
-from celery.task import task
+from celery import shared_task
 
 from django.utils import timezone
 from django.utils.module_loading import import_string
@@ -8,7 +8,7 @@ from django.utils.module_loading import import_string
 from .models import ImportTask
 
 
-@task(track_started=True)
+@shared_task(track_started=True)
 def csv_import(task_id):  # pragma: no cover
     task_obj = ImportTask.objects.get(pk=task_id)
     log = StringIO()
